# stuff that didn't fit in CMF.py or __init__.py

from types import *
import string, re, os
from AccessControl import getSecurityManager
from DateTime import DateTime
from Globals import package_home
from ZWikiPage import ZWikiPage
from CMF import CMFWikiFolder
import Permissions
from Defaults import PAGE_METATYPE, PAGE_PORTALTYPE, \
     WIKI_METATYPE, WIKI_PORTALTYPE

wiki_globals=globals()

default_perms = {
    'create': 'nonanon',
    'edit': 'nonanon',
    'comment': 'nonanon',
    'move': 'owners', # rename/delete/reparent
    'regulate': 'owners'
    }

def initPageMetadata(page):
    page.creation_date = DateTime()
    page._editMetadata(title='',
                       subject=(),
                       description='',
                       contributors=(),
                       effective_date=None,
                       expiration_date=None,
                       format='text_html',
                       language='',
                       rights = '')

def makeCMFWikiPage(id, title, file):
    ob = ZWikiPage(source_string=file, __name__=id)
    ob.title = title
    ob.parents = []
    username = getSecurityManager().getUser().getUserName()
    ob.manage_addLocalRoles(username, ['Owner'])
    ob._getRegs().setSubOwner('both')
    initPageMetadata(ob)
    #for name, perm in ob._perms.items():
    #    pseudoperm = default_perms[name]
    #    local_roles_map = ob._local_roles_map
    #    roles_map = ob._roles_map
    #    roles = (local_roles_map[name],) + roles_map[pseudoperm]
    #    ob.manage_permission(perm, roles=roles)
    return ob

def addWikiPage(self, id, title='', file=''):
    id=str(id)
    title=str(title)
    ob = makeCMFWikiPage(id, title, file)
    self._setObject(id, ob)

def addWikiFolder(self, id, title=''):
    id = str(id)
    title = str(title)
    ob = CMFWikiFolder(id, title)
    id = self._setObject(id, ob)
    ob = getattr(self, id)
    p = package_home(globals()) + os.sep + 'default_wiki_content'
    fnames = os.listdir(p)
    for fname in fnames:
        if fname[-5:] != '.wiki': continue
        f = open(p + os.sep + fname, 'r')
        fname = fname[:-5]#
        addWikiPage(ob, fname, title='', file=f.read())
        page = getattr(ob, fname)
        page.indexObject()
        # Hack - may be ok if we continue to have, like, only two pages:
        if fname == 'SandBox':
            page.parents = ['FrontPage']

factory_type_information = (
    {'id': PAGE_PORTALTYPE,
     'content_icon': 'wikipage_icon.gif',
     'meta_type': PAGE_METATYPE,
     'product': 'ZWiki',
     'factory': 'addWikiPage',
     'immediate_view': 'wikipage_view',
     'actions': ({'id': 'view',
                  'name': 'View',
                  'action': 'wikipage_view',
                  'permissions': (Permissions.View,)},
                 {'id': 'comment',
                  'name': 'Comment',
                  'action': 'wikipage_comment_form',
                  'permissions': (Permissions.Comment,)},
                 {'id': 'edit',
                  'name': 'Edit',
                  'action': 'wikipage_edit_form',
                  'permissions': (Permissions.Edit,)},
                 {'id': 'history',
                  'name': 'History',
                  'action': 'wikipage_history',
                  'permissions': (Permissions.View,)},
                 {'id': 'backlinks',
                  'name': 'Backlinks',
                  'action': 'wikipage_backlinks',
                  'permissions': (Permissions.View,)},
                 {'id': 'advanced',
                  'name': 'Advanced',
                  'action': 'wikipage_advanced_form',
                  'permissions': (Permissions.View,)},
                 {'id': 'toc',
                  'name': 'Wiki Contents',
                  'category': 'folder',
                  'action':'wikipage_toc',
                  'permissions': (Permissions.View,)},
                 {'id': 'recent_changes',
                  'name': 'Recent Changes',
                  'category': 'folder',
                  'action':'wikipage_recentchanges',
                  'permissions': (Permissions.View,)},
                 {'id': 'create',
                  'name': 'Create',
                  'category': 'folder',
                  'action':'wikipage_create_form',
                  'permissions': (Permissions.Create,),
                  'visible': 0 },
                 ),
     },
    {'id': WIKI_PORTALTYPE,
     'content_icon': 'folder_icon.gif',
     'meta_type': WIKI_METATYPE,
     'description': ('Loosely organized (yet structured) content can be '
                     'added to Wikis.'),
     'product': 'ZWiki',
     'factory': 'addWikiFolder',
     'immediate_view': 'FrontPage',
     'actions': ({'id': 'toc',
                  'name': 'Wiki Contents',
                  'category': 'folder',
                  'action':'wiki_toc',
                  'permissions': (Permissions.View,)},
                 {'id': 'view',
                  'name': 'FrontPage',
                  'category': 'folder',
                  'action':'FrontPage',
                  'permissions': (Permissions.View,)},
                 {'id': 'all',
                  'name': 'All Pages',
                  'category': 'folder',
                  'action':'wiki_allpages',
                  'permissions': (Permissions.View,)},
                 {'id': 'recent_changes',
                  'name': 'Recent Changes',
                  'category': 'folder',
                  'action':'wiki_recentchanges',
                  'permissions': (Permissions.View,)},
                 {'id': 'wikihelp',
                  'name': 'WikiHelp',
                  'category': 'folder',
                  'action': 'WikiHelp',
                  'permissions': (Permissions.View,)}
                 ),
     },
    )

from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerDirectory
from Products.CMFCore.PortalFolder import PortalFolder
from Permissions import Create

def initialize(context): 
    """Initialize the ZWiki product for use in CMF.
    """
    registerDirectory('skins', globals())
    utils.ContentInit(
        'Wiki Content',
        content_types = (ZWikiPage, PortalFolder),
        permission = Create,
        extra_constructors = (addWikiPage, addWikiFolder),
        fti = factory_type_information,
        ).initialize(context)
